@@ -387,8 +387,8 @@ class SettingsComponent(object):
             '    on %s\n' % (version, localDateTime) +
             'If you publish work using this script the most relevant '
             'publication is:\n\n'            
-            '    Peirce J, Gray JR, Simpson S, MacAskill M, Höchenberger R, Sogo H, '
-            'Kastman E, Lindeløv JK. (2019) \n'
+            u'    Peirce J, Gray JR, Simpson S, MacAskill M, Höchenberger R, Sogo H, '
+            u'Kastman E, Lindeløv JK. (2019) \n'
             '        PsychoPy2: Experiments in behavior made easy Behav Res 51: 195. \n'
             '        https://doi.org/10.3758/s13428-018-01193-y\n'
             '\n"""\n'
