@@ -3,6 +3,7 @@
 # Copyright (C) 2012-2016 iSolver Software Solutions
 # Distributed under the terms of the GNU General Public License (GPL).
 import serial
+import sys
 import numpy as N
 from ... import EXP_SCRIPT_DIRECTORY
 from .. import Device, DeviceEvent, Computer
@@ -10,6 +11,8 @@ from ...errors import print2err, printExceptionDetailsToStdErr
 from ...constants import DeviceConstants, EventConstants
 getTime = Computer.getTime
 
+PY3 = sys.version_info.major >= 3
+
 
 class Serial(Device):
     """A general purpose serial input interface device.
@@ -280,7 +283,7 @@ class Serial(Device):
         self._serial.flushInput()
         inBytes = self._serial.inWaiting()
         if inBytes > 0:
-            self._serial.read(inBytes)
+            self._serial.read(inBytes)  # empty buffer and discard
         if self._byte_diff_mode:
             self._rx_buffer = None
         else:
@@ -293,13 +296,18 @@ class Serial(Device):
         self._serial.flush()
 
     def write(self, bytestring):
+        if type(bytestring) != bytes:
+            bytestring = bytestring.encode('utf-8')
         tx_count = self._serial.write(bytestring)
         self._serial.flush()
         return tx_count
 
     def read(self):
-        return self._serial.read(self._serial.inWaiting())
-
+        returned = self._serial.read(self._serial.inWaiting())
+        if PY3:
+            returned = returned.decode('utf-8')
+        return returned
+		
     def closeSerial(self):
         if self._serial:
             self._serial.close()
@@ -537,7 +545,7 @@ class Pstbox(Serial):
 
         # Convert the new state into a bitmask, collapse it into a
         # single byte and send it to the response box.
-        state_bits = (2**N.arange(9))[state]
+        state_bits = (2**N.arange(8))[state]
         self.write(chr(N.sum(state_bits)))
 
         # Set the `update lamp` bit to LOW again.
